@@ -10,6 +10,7 @@ import (
 
 	"github.com/aelsabbahy/goss"
 	"github.com/aelsabbahy/goss/outputs"
+	"github.com/aelsabbahy/goss/resource"
 	"github.com/aelsabbahy/goss/system"
 	"github.com/aelsabbahy/goss/util"
 
@@ -239,77 +240,77 @@ func main() {
 			},
 			Subcommands: []cli.Command{
 				{
-					Name:  "package",
+					Name:  resource.PackageResourceKey,
 					Usage: "add new package",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Package", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.PackageResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "file",
+					Name:  resource.FileResourceKey,
 					Usage: "add new file",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "File", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.FileResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "addr",
+					Name:  resource.AddrResourceKey,
 					Usage: "add new remote address:port - ex: google.com:80",
 					Flags: []cli.Flag{
 						timeoutFlag(500 * time.Millisecond),
 					},
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Addr", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.AddResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "port",
+					Name:  resource.PortResourceKey,
 					Usage: "add new listening [protocol]:port - ex: 80 or udp:123",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Port", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.PortResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "service",
+					Name:  resource.ServiceResourceKey,
 					Usage: "add new service",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Service", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.ServiceResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "user",
+					Name:  resource.UserResourceKey,
 					Usage: "add new user",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "User", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.UserResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "group",
+					Name:  resource.GroupResourceKey,
 					Usage: "add new group",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Group", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.GroupResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "command",
+					Name:  resource.CommandResourceKey,
 					Usage: "add new command",
 					Flags: []cli.Flag{
 						timeoutFlag(10 * time.Second),
 					},
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Command", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.CommandResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "dns",
+					Name:  resource.DNSResourceKey,
 					Usage: "add new dns",
 					Flags: []cli.Flag{
 						timeoutFlag(500 * time.Millisecond),
@@ -320,19 +321,19 @@ func main() {
 					},
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "DNS", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.DNSResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "process",
+					Name:  resource.ProcessResourceKey,
 					Usage: "add new process name",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Process", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.ProcessResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "http",
+					Name:  resource.HTTPResourceKey,
 					Usage: "add new http",
 					Flags: []cli.Flag{
 						cli.BoolFlag{
@@ -357,7 +358,7 @@ func main() {
 					},
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "HTTP", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.HTTPResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
@@ -365,32 +366,32 @@ func main() {
 					Usage: "add new goss file, it will be imported from this one",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Gossfile", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.GossFileResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 
 					},
 				},
 				{
-					Name:  "kernel-param",
+					Name:  resource.KernelParamResourceKey,
 					Usage: "add new goss kernel param",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "KernelParam", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.KernelParamResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "mount",
+					Name:  resource.MountResourceKey,
 					Usage: "add new mount",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Mount", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.MountResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 				{
-					Name:  "interface",
+					Name:  resource.InterfaceResourceKey,
 					Usage: "add new interface",
 					Action: func(c *cli.Context) error {
 						fatalAlphaIfNeeded(c)
-						return goss.AddResources(c.GlobalString("gossfile"), "Interface", c.Args(), newRuntimeConfigFromCLI(c))
+						return goss.AddResources(c.GlobalString("gossfile"), resource.InterfaceResourceName, c.Args(), newRuntimeConfigFromCLI(c))
 					},
 				},
 			},
