@@ -25,8 +25,10 @@ touch "$INSTALL_LOC" || { echo "ERROR: Cannot write to $GOSS_DST set GOSS_DST el
 arch=""
 if [ "$(uname -m)" = "x86_64" ]; then
     arch="amd64"
-elif [ "$(uname -m)" = "aarch64" ]; then
+elif [ "$(uname -m)" = "aarch32" ]; then
     arch="arm"
+elif [ "$(uname -m)" = "aarch64" ] || [ "$(uname -m)" = "arm64" ]; then
+    arch="arm64"
 else
     arch="386"
 fi
